@@ -16,6 +16,8 @@ from .internal_utils import (
 class WebClient(BaseClient):
     """A WebClient allows apps to communicate with the Slack Platform's Web API.
 
+    https://api.slack.com/methods
+
     The Slack Web API is an interface for querying information from
     and enacting change in a Slack workspace.
 
@@ -471,6 +473,71 @@ class WebClient(BaseClient):
         """Lists all active user sessions for an organization"""
         return self.api_call("admin.users.session.list", params=kwargs)
 
+    def admin_teams_settings_setDefaultChannels(
+        self, *, team_id: str, channel_ids: Union[str, Sequence[str]], **kwargs
+    ) -> SlackResponse:
+        """Set the default channels of a workspace.
+
+        Args:
+            team_id (str): ID of the team.
+            channel_ids (str or list): A list of channel_ids.
+                At least one channel is required. e.g. ['C1A2B3C4D', 'C26Z25Y24']
+        """
+        kwargs.update({"team_id": team_id})
+        if isinstance(channel_ids, (list, Tuple)):
+            kwargs.update({"channel_ids": ",".join(channel_ids)})
+        else:
+            kwargs.update({"channel_ids": channel_ids})
+        return self.api_call(
+            "admin.teams.settings.setDefaultChannels", http_verb="GET", params=kwargs
+        )
+
+    def admin_users_session_getSettings(
+        self, *, user_ids: Union[str, Sequence[str]], **kwargs
+    ) -> SlackResponse:
+        """Get user-specific session settings—the session duration
+        and what happens when the client closes—given a list of users.
+
+        Args:
+            user_ids (str or list): The IDs of users you'd like to fetch session settings for.
+                Note: if a user does not have any active sessions, they will not be returned in the response.
+        """
+        if isinstance(user_ids, (list, Tuple)):
+            kwargs.update({"user_ids": ",".join(user_ids)})
+        else:
+            kwargs.update({"user_ids": user_ids})
+        return self.api_call("admin.users.session.getSettings", json=kwargs)
+
+    def admin_users_session_setSettings(
+        self, *, user_ids: Union[str, Sequence[str]], **kwargs
+    ) -> SlackResponse:
+        """Configure the user-level session settings—the session duration
+        and what happens when the client closes—for one or more users.
+
+        Args:
+            user_ids (str or list): The list of user IDs to apply the session settings for.
+        """
+        if isinstance(user_ids, (list, Tuple)):
+            kwargs.update({"user_ids": ",".join(user_ids)})
+        else:
+            kwargs.update({"user_ids": user_ids})
+        return self.api_call("admin.users.session.setSettings", json=kwargs)
+
+    def admin_users_session_clearSettings(
+        self, *, user_ids: Union[str, Sequence[str]], **kwargs
+    ) -> SlackResponse:
+        """Clear user-specific session settings—the session duration
+        and what happens when the client closes—for a list of users.
+
+        Args:
+            user_ids (str or list): The list of user IDs to apply the session settings for.
+        """
+        if isinstance(user_ids, (list, Tuple)):
+            kwargs.update({"user_ids": ",".join(user_ids)})
+        else:
+            kwargs.update({"user_ids": user_ids})
+        return self.api_call("admin.users.session.clearSettings", json=kwargs)
+
     def admin_inviteRequests_approve(
         self, *, invite_request_id: str, **kwargs
     ) -> SlackResponse:
@@ -550,25 +617,6 @@ class WebClient(BaseClient):
         kwargs.update({"team_id": team_id})
         return self.api_call("admin.teams.settings.info", json=kwargs)
 
-    def admin_teams_settings_setDefaultChannels(
-        self, *, team_id: str, channel_ids: Union[str, Sequence[str]], **kwargs
-    ) -> SlackResponse:
-        """Set the default channels of a workspace.
-
-        Args:
-            team_id (str): ID of the team.
-            channel_ids (str or list): A list of channel_ids.
-                At least one channel is required. e.g. ['C1A2B3C4D', 'C26Z25Y24']
-        """
-        kwargs.update({"team_id": team_id})
-        if isinstance(channel_ids, (list, Tuple)):
-            kwargs.update({"channel_ids": ",".join(channel_ids)})
-        else:
-            kwargs.update({"channel_ids": channel_ids})
-        return self.api_call(
-            "admin.teams.settings.setDefaultChannels", http_verb="GET", params=kwargs
-        )
-
     def admin_teams_settings_setDescription(
         self, *, team_id: str, description: str, **kwargs
     ) -> SlackResponse:
@@ -1114,7 +1162,7 @@ class WebClient(BaseClient):
             user (str): The id of user who should see the message. e.g. 'U0BPQUNTA'
             text (str): The message you'd like to share. e.g. 'Hello world'
                 text is not required when presenting blocks.
-            blocks (list): A dictionary list of blocks.
+            blocks (list): A list of either dict values or `slack_sdk.models.blocks.Block` objects.
                 Blocks are required when not presenting text.
                 e.g. [{"type": "section", "text": {"type": "plain_text", "text": "Hello world"}}]
         """
@@ -1130,7 +1178,7 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             text (str): The message you'd like to share. e.g. 'Hello world'
                 text is not required when presenting blocks.
-            blocks (list): A dictionary list of blocks.
+            blocks (list): A list of either dict values or `slack_sdk.models.blocks.Block` objects.
                 Blocks are required when not presenting text.
                 e.g. [{"type": "section", "text": {"type": "plain_text", "text": "Hello world"}}]
         """
@@ -1176,7 +1224,7 @@ class WebClient(BaseClient):
             ts (str): Timestamp of the message to be updated. e.g. '1234567890.123456'
             text (str): The message you'd like to share. e.g. 'Hello world'
                 text is not required when presenting blocks.
-            blocks (list): A dictionary list of blocks.
+            blocks (list): A list of either dict values or `slack_sdk.models.blocks.Block` objects.
                 Blocks are required when not presenting text.
                 e.g. [{"type": "section", "text": {"type": "plain_text", "text": "Hello world"}}]
         """
